@@ -1,50 +1,8 @@
 ﻿from PyQt4 import Qt, QtGui, QtCore
+from nustudio import ArrayTableModel
 from nustudio.ui import Global
 from nustudio.htm.node import NodeType, Node
 
-class ArrayTableModel(QtGui.QStandardItemModel):
-
-	def __init__(self, parent=None):
-		QtGui.QStandardItemModel.__init__(self)
-
-		self.header = []
-		self.data = []
-
-	def update(self, header, data):
-		self.header = header
-		self.data = data
-
-		numCols = len(self.header)
-		self.setColumnCount(numCols)
-		numRows = len(self.data)
-		self.setRowCount(numRows)
-
-		for col in range(numCols):
-			self.setHeaderData(col, QtCore.Qt.Horizontal, self.header[col])
-
-		for row in range(numRows):
-			for col in range(numCols):
-				data = self.data[row][col]
-				self.setData(self.index(row, col, QtCore.QModelIndex()), data)
-
-	def data(self, index, role=QtCore.Qt.DisplayRole):
-		column, row = index.column(), index.row()
-		if role == QtCore.Qt.TextAlignmentRole:
-			if column > 0:
-				return QtCore.Qt.AlignLeft
-			else:
-				return QtCore.Qt.AlignRight
-		elif role == QtCore.Qt.DisplayRole:
-			return self.data[row][column]
-		return 
-
-	def columnCount(self, parent=QtCore.QModelIndex()):
-		return len(self.header)
-
-	def rowCount(self, parent=QtCore.QModelIndex()):
-		return len(self.data)
-
-
 class NodeInformationForm(QtGui.QWidget):
 
 	#region Constructor
@@ -88,34 +46,34 @@ class NodeInformationForm(QtGui.QWidget):
 		self.textBoxSensorName.setEnabled(False)
 		self.textBoxSensorName.setAlignment(QtCore.Qt.AlignLeft)
 
-		# labelEncodedInput
-		self.labelEncodedInput = QtGui.QLabel()
-		self.labelEncodedInput.setText("Encoded Input")
-		self.labelEncodedInput.setAlignment(QtCore.Qt.AlignRight)
+		# labelCurrentValue
+		self.labelCurrentValue = QtGui.QLabel()
+		self.labelCurrentValue.setText("Current Value")
+		self.labelCurrentValue.setAlignment(QtCore.Qt.AlignRight)
 
-		# textBoxEncodedInput
-		self.textBoxEncodedInput = QtGui.QLineEdit()
-		self.textBoxEncodedInput.setEnabled(False)
-		self.textBoxEncodedInput.setAlignment(QtCore.Qt.AlignRight)
+		# textBoxCurrentValue
+		self.textBoxCurrentValue = QtGui.QLineEdit()
+		self.textBoxCurrentValue.setEnabled(False)
+		self.textBoxCurrentValue.setAlignment(QtCore.Qt.AlignRight)
 
-		# labelDecodedOutput
-		self.labelDecodedOutput = QtGui.QLabel()
-		self.labelDecodedOutput.setText("Decoded Output")
-		self.labelDecodedOutput.setAlignment(QtCore.Qt.AlignRight)
+		# labelPredictedValue
+		self.labelPredictedValue = QtGui.QLabel()
+		self.labelPredictedValue.setText("Predicted Value")
+		self.labelPredictedValue.setAlignment(QtCore.Qt.AlignRight)
 
-		# textBoxRegionDecodedOutput
-		self.textBoxRegionDecodedOutput = QtGui.QLineEdit()
-		self.textBoxRegionDecodedOutput.setEnabled(False)
-		self.textBoxRegionDecodedOutput.setAlignment(QtCore.Qt.AlignRight)
+		# textBoxPredictedValue
+		self.textBoxPredictedValue = QtGui.QLineEdit()
+		self.textBoxPredictedValue.setEnabled(False)
+		self.textBoxPredictedValue.setAlignment(QtCore.Qt.AlignRight)
 
 		# tabPageSensorLayout
 		self.tabPageSensorLayout = QtGui.QGridLayout()
 		self.tabPageSensorLayout.addWidget(self.labelSensorName, 0, 0)
 		self.tabPageSensorLayout.addWidget(self.textBoxSensorName, 0, 1)
-		self.tabPageSensorLayout.addWidget(self.labelEncodedInput, 1, 0)
-		self.tabPageSensorLayout.addWidget(self.textBoxEncodedInput, 1, 1)
-		self.tabPageSensorLayout.addWidget(self.labelDecodedOutput, 2, 0)
-		self.tabPageSensorLayout.addWidget(self.textBoxRegionDecodedOutput, 2, 1)
+		self.tabPageSensorLayout.addWidget(self.labelCurrentValue, 1, 0)
+		self.tabPageSensorLayout.addWidget(self.textBoxCurrentValue, 1, 1)
+		self.tabPageSensorLayout.addWidget(self.labelPredictedValue, 2, 0)
+		self.tabPageSensorLayout.addWidget(self.textBoxPredictedValue, 2, 1)
 		self.tabPageSensorLayout.setRowStretch(3, 100)
 		self.tabPageSensorLayout.setColumnStretch(2, 100)
 
@@ -125,7 +83,7 @@ class NodeInformationForm(QtGui.QWidget):
 
 		# dataGridBits
 		self.dataGridBits = QtGui.QTableView()
-		self.dataGridBits.setModel(ArrayTableModel())
+		self.dataGridBits.setModel(ArrayTableModel(QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsSelectable))
 		self.dataGridBits.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
 		self.dataGridBits.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
 		self.dataGridBits.setToolTip("Click on a row to see more details")
@@ -162,7 +120,7 @@ class NodeInformationForm(QtGui.QWidget):
 
 		# dataGridColumns
 		self.dataGridColumns = QtGui.QTableView()
-		self.dataGridColumns.setModel(ArrayTableModel())
+		self.dataGridColumns.setModel(ArrayTableModel(QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsSelectable))
 		self.dataGridColumns.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
 		self.dataGridColumns.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
 		self.dataGridColumns.setToolTip("Click on a row to see more details")
@@ -179,7 +137,7 @@ class NodeInformationForm(QtGui.QWidget):
 
 		# dataGridProximalSynapses
 		self.dataGridProximalSynapses = QtGui.QTableView()
-		self.dataGridProximalSynapses.setModel(ArrayTableModel())
+		self.dataGridProximalSynapses.setModel(ArrayTableModel(QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsSelectable))
 		self.dataGridProximalSynapses.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
 		self.dataGridProximalSynapses.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
 		self.dataGridProximalSynapses.setToolTip("Click on a row to see more details")
@@ -196,7 +154,7 @@ class NodeInformationForm(QtGui.QWidget):
 
 		# dataGridCells
 		self.dataGridCells = QtGui.QTableView()
-		self.dataGridCells.setModel(ArrayTableModel())
+		self.dataGridCells.setModel(ArrayTableModel(QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsSelectable))
 		self.dataGridCells.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
 		self.dataGridCells.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
 		self.dataGridCells.setToolTip("Click on a row to see more details")
@@ -213,7 +171,7 @@ class NodeInformationForm(QtGui.QWidget):
 
 		# dataGridDistalSegments
 		self.dataGridDistalSegments = QtGui.QTableView()
-		self.dataGridDistalSegments.setModel(ArrayTableModel())
+		self.dataGridDistalSegments.setModel(ArrayTableModel(QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsSelectable))
 		self.dataGridDistalSegments.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
 		self.dataGridDistalSegments.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
 		self.dataGridDistalSegments.setToolTip("Click on a row to see more details")
@@ -230,7 +188,7 @@ class NodeInformationForm(QtGui.QWidget):
 
 		# dataGridDistalSynapses
 		self.dataGridDistalSynapses = QtGui.QTableView()
-		self.dataGridDistalSynapses.setModel(ArrayTableModel())
+		self.dataGridDistalSynapses.setModel(ArrayTableModel(QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsSelectable))
 		self.dataGridDistalSynapses.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
 		self.dataGridDistalSynapses.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
 		self.dataGridDistalSynapses.setToolTip("Click on a row to see more details")
@@ -289,19 +247,6 @@ class NodeInformationForm(QtGui.QWidget):
 		if selectedNode.type == NodeType.region:
 			self.selectedRegion = selectedNode
 
-			"""TODO:# Update node controls
-			self.textBoxRegionStepCounter.setText("")
-			self.textBoxRegionActivityRate.setText("")
-			self.textBoxRegionPredictionPrecision.setText("")
-			self.textBoxRegionPredictionCounter.setText("")
-			self.textBoxRegionCorrectPredictionCounter.setText("")
-			if selectedRegion != None:
-				self.textBoxRegionStepCounter.setText(selectedRegion.Statistics.StepCounter.ToString())
-				self.textBoxRegionActivityRate.setText(selectedRegion.Statistics.ActivityRate.ToString())
-				self.textBoxRegionPredictionPrecision.setText(selectedRegion.Statistics.PredictPrecision.ToString())
-				self.textBoxRegionPredictionCounter.setText(selectedRegion.Statistics.PredictionCounter.ToString())
-				self.textBoxRegionCorrectPredictionCounter.setText(selectedRegion.Statistics.CorrectPredictionCounter.ToString())"""
-
 			# Bind the columns from this region
 			header, data = self.getColumnsData(self.selectedRegion)
 			self.dataGridColumns.model().update(header, data)
@@ -324,8 +269,8 @@ class NodeInformationForm(QtGui.QWidget):
 			pos = str(bit.x) + ", " + str(bit.y)
 			wasPredicted = bit.isPredicted[Global.selStep - 1]
 			isActive = bit.isActive[Global.selStep]
-			activationRate = bit.statsActivationRate
-			precisionRate = bit.statsPrecisionRate
+			activationRate = "{0:.3f}".format(bit.statsActivationRate)
+			precisionRate = "{0:.3f}".format(bit.statsPrecisionRate)
 			data.append([pos, wasPredicted, isActive, activationRate, precisionRate])
 
 		return header, data
@@ -337,8 +282,8 @@ class NodeInformationForm(QtGui.QWidget):
 			pos = str(column.x) + ", " + str(column.y)
 			wasPredicted = column.segment.isPredicted[Global.selStep - 1]
 			isActive = column.segment.isActive[Global.selStep]
-			activationRate = column.segment.statsActivationRate
-			precisionRate = column.segment.statsPrecisionRate
+			activationRate = "{0:.3f}".format(column.segment.statsActivationRate)
+			precisionRate = "{0:.3f}".format(column.segment.statsPrecisionRate)
 			data.append([pos, wasPredicted, isActive, activationRate, precisionRate])
 
 		return header, data
@@ -350,8 +295,8 @@ class NodeInformationForm(QtGui.QWidget):
 		for synapse in selectedSegment.synapses:
 			permanence = "{0:.3f}".format(synapse.permanence[Global.selStep])
 			isConnected = synapse.isConnected[Global.selStep]
-			connectionRate = synapse.statsConnectionRate
-			precisionRate = synapse.statsPrecisionRate
+			connectionRate = "{0:.3f}".format(synapse.statsConnectionRate)
+			precisionRate = "{0:.3f}".format(synapse.statsPrecisionRate)
 			data.append([permanence, isConnected, connectionRate, precisionRate])
 
 		return header, data
@@ -363,8 +308,8 @@ class NodeInformationForm(QtGui.QWidget):
 			pos = str(cell.z)
 			wasPredicted = cell.isPredicted[Global.selStep - 1]
 			isActive = cell.isActive[Global.selStep]
-			activationRate = cell.statsActivationRate
-			precisionRate = cell.statsPrecisionRate
+			activationRate = "{0:.3f}".format(cell.statsActivationRate)
+			precisionRate = "{0:.3f}".format(cell.statsPrecisionRate)
 			data.append([pos, wasPredicted, isActive, activationRate, precisionRate])
 
 		return header, data
@@ -374,7 +319,7 @@ class NodeInformationForm(QtGui.QWidget):
 		data = []
 		for segment in selectedCell.segments:
 			isActive = segment.isActive[Global.selStep]
-			activationRate = segment.statsActivationRate
+			activationRate = "{0:.3f}".format(segment.statsActivationRate)
 			data.append([isActive, activationRate, activationRate])
 
 		return header, data
@@ -386,7 +331,7 @@ class NodeInformationForm(QtGui.QWidget):
 		for synapse in selectedSegment.synapses:
 			permanence = "{0:.3f}".format(synapse.permanence[Global.selStep])
 			isConnected = synapse.isConnected[Global.selStep]
-			connectionRate = synapse.statsConnectionRate
+			connectionRate = "{0:.3f}".format(synapse.statsConnectionRate)
 			data.append([permanence, isConnected, connectionRate])
 
 		return header, data
